[gtk+] docs: fix a number of typos and obsolete references



commit f70fc49ebc999bc4e37c0807e818aeff2bca3459
Author: Cosimo Cecchi <cosimoc gnome org>
Date:   Mon Jul 2 02:19:06 2012 -0400

    docs: fix a number of typos and obsolete references

 docs/reference/gtk/gtk3-sections.txt             |    1 -
 docs/reference/gtk/migrating-GtkStyleContext.xml |    4 ++--
 docs/reference/gtk/migrating-checklist.sgml      |    2 +-
 gtk/deprecated/gtkcolorseldialog.c               |    2 +-
 gtk/deprecated/gtkfontsel.c                      |    2 +-
 gtk/deprecated/gtkrc.c                           |    2 +-
 gtk/gtkaccelgroup.c                              |    2 ++
 gtk/gtkactionable.c                              |    6 +++---
 gtk/gtkactiongroup.c                             |    5 +++--
 gtk/gtkactivatable.c                             |    3 ++-
 gtk/gtkadjustment.c                              |   10 +++++-----
 gtk/gtkapplication.c                             |   15 ++++++++-------
 gtk/gtkapplicationwindow.c                       |    2 +-
 gtk/gtkcelleditable.c                            |    4 ++--
 gtk/gtkcelllayout.c                              |    4 ++--
 gtk/gtkcellrenderercombo.c                       |    2 +-
 gtk/gtkcssprovider.c                             |    2 +-
 gtk/gtkcsssection.c                              |    4 ++--
 gtk/gtkentry.c                                   |    6 +++---
 gtk/gtkfilechooserdialog.c                       |    2 +-
 gtk/gtkiconview.c                                |    2 +-
 gtk/gtklabel.c                                   |    8 ++++----
 gtk/gtkmain.c                                    |    5 ++---
 gtk/gtkmenu.c                                    |    6 +++---
 gtk/gtknotebook.c                                |    2 +-
 gtk/gtkprintoperation.c                          |    8 ++++----
 gtk/gtkprintunixdialog.c                         |    2 +-
 gtk/gtkprogressbar.c                             |    2 +-
 gtk/gtkradiotoolbutton.c                         |    2 +-
 gtk/gtkrecentchooser.h                           |    2 +-
 gtk/gtkscrollbar.c                               |   12 ++++++------
 gtk/gtkselection.c                               |    4 ++--
 gtk/gtkselection.h                               |    2 +-
 gtk/gtkseparatortoolitem.c                       |    2 +-
 gtk/gtkstatusbar.c                               |   10 +++++-----
 gtk/gtkthemingengine.c                           |    4 ++--
 gtk/gtktogglebutton.c                            |    2 +-
 gtk/gtktoolbutton.c                              |    2 +-
 gtk/gtktoolitem.c                                |    7 ++-----
 gtk/gtktoolpalette.c                             |    6 +++---
 gtk/gtktreeview.c                                |    4 ++--
 gtk/gtktreeviewcolumn.c                          |    6 +++---
 gtk/gtktreeviewcolumn.h                          |    2 +-
 gtk/gtkviewport.c                                |    2 +-
 gtk/gtkwidget.c                                  |   20 ++++++++++----------
 gtk/gtkwidget.h                                  |    2 +-
 gtk/gtkwindow.c                                  |    8 ++++----
 47 files changed, 107 insertions(+), 107 deletions(-)
---
diff --git a/docs/reference/gtk/gtk3-sections.txt b/docs/reference/gtk/gtk3-sections.txt
index d435188..7a04b30 100644
--- a/docs/reference/gtk/gtk3-sections.txt
+++ b/docs/reference/gtk/gtk3-sections.txt
@@ -3167,7 +3167,6 @@ GTK_TYPE_SPINNER
 GTK_SPINNER_CLASS
 GTK_IS_SPINNER_CLASS
 GTK_SPINNER_GET_CLASS
-GTK_IS_SPINNER_CLASS
 
 <SUBSECTION Private>
 GtkSpinnerPrivate
diff --git a/docs/reference/gtk/migrating-GtkStyleContext.xml b/docs/reference/gtk/migrating-GtkStyleContext.xml
index bea2629..6ef11c5 100644
--- a/docs/reference/gtk/migrating-GtkStyleContext.xml
+++ b/docs/reference/gtk/migrating-GtkStyleContext.xml
@@ -134,7 +134,7 @@
     </simplelist>
 
     <para>
-      One of the main differences to #GtkStyle-based engines is that the
+      One of the main differences to #GtkStyle<!-- -->-based engines is that the
       rendered widget is totally isolated from the theme engine, all style
       information is meant to be retrieved from the #GtkThemingEngine API,
       or from the #GtkWidgetPath obtained from gtk_theming_engine_get_path(),
@@ -171,7 +171,7 @@
     </para>
 
     <para>
-      The installed properties depend on the #GtkThemeEngine::name property,
+      The installed properties depend on the #GtkThemingEngine:name property,
       so they should be added in the <literal>constructed()</literal> vfunc.
       For example, if an engine with the name "Clearlooks" installs a
       "focus-color" property with the type #GdkRGBA, the property
diff --git a/docs/reference/gtk/migrating-checklist.sgml b/docs/reference/gtk/migrating-checklist.sgml
index 659dad9..3932926 100644
--- a/docs/reference/gtk/migrating-checklist.sgml
+++ b/docs/reference/gtk/migrating-checklist.sgml
@@ -295,7 +295,7 @@ my_widget_key_press_event_handler (GtkWidget *widget, GdkEventKey *event)
 
     <para>
       Named icons can be used for window icons (see gtk_window_set_icon_name())
-      and images (see gtk_image_set_icon_name()). You can also use named icons
+      and images (see gtk_image_set_from_icon_name()). You can also use named icons
       for drag-and-drop (see gtk_drag_source_set_icon_name()) and in treeview
       cells (see the #GtkCellRendererPixbuf:icon-name property).
     </para>
diff --git a/gtk/deprecated/gtkcolorseldialog.c b/gtk/deprecated/gtkcolorseldialog.c
index 6071659..d5e9d66 100644
--- a/gtk/deprecated/gtkcolorseldialog.c
+++ b/gtk/deprecated/gtkcolorseldialog.c
@@ -42,7 +42,7 @@
  * @Title: GtkColorSelectionDialog
  *
  * The #GtkColorSelectionDialog provides a standard dialog which
- * allows the user to select a color much like the #GtkFileSelection
+ * allows the user to select a color much like the #GtkFileChooserDialog
  * provides a standard dialog for file selection.
  *
  * Use gtk_color_selection_dialog_get_color_selection() to get the
diff --git a/gtk/deprecated/gtkfontsel.c b/gtk/deprecated/gtkfontsel.c
index 74054ad..10db4cc 100644
--- a/gtk/deprecated/gtkfontsel.c
+++ b/gtk/deprecated/gtkfontsel.c
@@ -1293,7 +1293,7 @@ gtk_font_selection_get_size_entry (GtkFontSelection *fontsel)
  * gtk_font_selection_get_size_list:
  * @fontsel: a #GtkFontSelection
  *
- * This returns the #GtkTreeeView used to list font sizes.
+ * This returns the #GtkTreeView used to list font sizes.
  *
  * Return value: (transfer none): A #GtkWidget that is part of @fontsel
  *
diff --git a/gtk/deprecated/gtkrc.c b/gtk/deprecated/gtkrc.c
index 2cb8005..568dc5c 100644
--- a/gtk/deprecated/gtkrc.c
+++ b/gtk/deprecated/gtkrc.c
@@ -1690,7 +1690,7 @@ gtk_rc_find_module_in_path (const gchar *module_file)
 
 /**
  * gtk_rc_parse_state:
- * @scanner: a #GtkScanner (must be initialized for parsing an RC file)
+ * @scanner: a #GScanner (must be initialized for parsing an RC file)
  * @state: (out): A pointer to a #GtkStateType variable in which to
  *  store the result.
  *
diff --git a/gtk/gtkaccelgroup.c b/gtk/gtkaccelgroup.c
index 442fa7a..c2d9102 100644
--- a/gtk/gtkaccelgroup.c
+++ b/gtk/gtkaccelgroup.c
@@ -1462,6 +1462,7 @@ gtk_accelerator_parse (const gchar     *accelerator,
  * gtk_accelerator_name_with_keycode:
  * @display: (allow-none): a #GdkDisplay or %NULL to use the default display
  * @accelerator_key: accelerator keyval
+ * @keycode: accelerator keycode
  * @accelerator_mods: accelerator modifier mask
  *
  * Converts an accelerator keyval and modifier mask
@@ -1647,6 +1648,7 @@ gtk_accelerator_name (guint           accelerator_key,
  * gtk_accelerator_get_label_with_keycode:
  * @display: (allow-none): a #GdkDisplay or %NULL to use the default display
  * @accelerator_key: accelerator keyval
+ * @keycode: accelerator keycode
  * @accelerator_mods: accelerator modifier mask
  *
  * Converts an accelerator keyval and modifier mask
diff --git a/gtk/gtkactionable.c b/gtk/gtkactionable.c
index c807967..dfb33d0 100644
--- a/gtk/gtkactionable.c
+++ b/gtk/gtkactionable.c
@@ -133,7 +133,7 @@ gtk_actionable_set_action_name (GtkActionable *actionable,
  *
  * Gets the current target value of @actionabe.
  *
- * See gtk_actionable_set_target_value() for more information.
+ * See gtk_actionable_set_action_target_value() for more information.
  *
  * Returns: (transfer none): the current target value
  *
@@ -224,8 +224,8 @@ gtk_actionable_set_action_target (GtkActionable *actionable,
  * actionable widget.
  *
  * This allows for the effect of both gtk_actionable_set_action_name()
- * and gtk_actionable_set_target() in the common case that the target is
- * string-valued.
+ * and gtk_actionable_set_action_target_value() in the common case that
+ * the target is string-valued.
  *
  * @detailed_action_name is a string of the form
  * <literal>"action::target"</literal> where <literal>action</literal>
diff --git a/gtk/gtkactiongroup.c b/gtk/gtkactiongroup.c
index e8504ec..5e94658 100644
--- a/gtk/gtkactiongroup.c
+++ b/gtk/gtkactiongroup.c
@@ -1363,7 +1363,7 @@ gtk_action_group_add_radio_actions_full (GtkActionGroup            *action_group
  *   destroyed and when the translation function is changed again
  *
  * Sets a function to be used for translating the @label and @tooltip of 
- * #GtkActionGroupEntry<!-- -->s added by gtk_action_group_add_actions().
+ * #GtkActionEntry<!-- -->s added by gtk_action_group_add_actions().
  *
  * If you're using gettext(), it is enough to set the translation domain
  * with gtk_action_group_set_translation_domain().
@@ -1434,7 +1434,8 @@ gtk_action_group_set_translation_domain (GtkActionGroup *action_group,
  * @action_group: a #GtkActionGroup
  * @string: a string
  *
- * Translates a string using the specified translate_func(). This
+ * Translates a string using the function set with 
+ * gtk_action_group_set_translate_func(). This
  * is mainly intended for language bindings.
  *
  * Returns: the translation of @string
diff --git a/gtk/gtkactivatable.c b/gtk/gtkactivatable.c
index 9dc786e..46ffa1b 100644
--- a/gtk/gtkactivatable.c
+++ b/gtk/gtkactivatable.c
@@ -409,7 +409,8 @@ gtk_activatable_action_notify (GtkAction      *action,
  *
  * <note><para>Be careful to call this before setting the local
  * copy of the #GtkAction property, since this function uses 
- * gtk_activatable_get_action() to retrieve the previous action</para></note>
+ * gtk_activatable_get_related_action() to retrieve the
+ * previous action</para></note>
  *
  * Since: 2.16
  */
diff --git a/gtk/gtkadjustment.c b/gtk/gtkadjustment.c
index 27b83d0..acba818 100644
--- a/gtk/gtkadjustment.c
+++ b/gtk/gtkadjustment.c
@@ -414,11 +414,11 @@ gtk_adjustment_get_value (GtkAdjustment *adjustment)
  * @value: the new value.
  *
  * Sets the #GtkAdjustment value. The value is clamped to lie between
- * #GtkAdjustment.lower and #GtkAdjustment.upper.
+ * #GtkAdjustment:lower and #GtkAdjustment:upper.
  *
  * Note that for adjustments which are used in a #GtkScrollbar, the effective
- * range of allowed values goes from #GtkAdjustment.lower to
- * #GtkAdjustment.upper - #GtkAdjustment.page_size.
+ * range of allowed values goes from #GtkAdjustment:lower to
+ * #GtkAdjustment:upper - #GtkAdjustment:page_size.
  */
 void
 gtk_adjustment_set_value (GtkAdjustment *adjustment,
@@ -769,9 +769,9 @@ gtk_adjustment_value_changed (GtkAdjustment *adjustment)
  * @lower: the lower value.
  * @upper: the upper value.
  *
- * Updates the #GtkAdjustment #GtkAdjustment.value to ensure that the range
+ * Updates the #GtkAdjustment #GtkAdjustment:value to ensure that the range
  * between @lower and @upper is in the current page (i.e. between
- * #GtkAdjustment.value and #GtkAdjustment.value + #GtkAdjustment.page_size).
+ * #GtkAdjustment:value and #GtkAdjustment:value + #GtkAdjustment:page_size).
  * If the range is larger than the page size, then only the start of it will
  * be in the current page.
  * A #GtkAdjustment::changed signal will be emitted if the value is changed.
diff --git a/gtk/gtkapplication.c b/gtk/gtkapplication.c
index fd11c96..f0e77bf 100644
--- a/gtk/gtkapplication.c
+++ b/gtk/gtkapplication.c
@@ -79,7 +79,7 @@
  * gtk_application_set_app_menu(). The #GMenuModel that this function
  * expects is usually constructed using #GtkBuilder, as seen in the
  * following example. To specify a menubar that will be shown by
- * #GApplicationWindows, use gtk_application_set_menubar(). Use the base
+ * #GtkApplicationWindow<!-- -->s, use gtk_application_set_menubar(). Use the base
  * #GActionMap interface to add actions, to respond to the user
  * selecting these menu items.
  *
@@ -763,7 +763,7 @@ gtk_application_class_init (GtkApplicationClass *class)
  * as soon as the application gets registered as the primary instance.
  *
  * Concretely, gtk_init() is called in the default handler for the
- * #GApplication:startup signal. Therefore, #GtkApplication subclasses should
+ * #GApplication::startup signal. Therefore, #GtkApplication subclasses should
  * chain up in their #GApplication:startup handler before using any GTK+ API.
  *
  * Note that commandline arguments are not passed to gtk_init().
@@ -923,7 +923,8 @@ gtk_application_get_window_by_id (GtkApplication *application,
  * is pressed.
  *
  * @accelerator must be a string that can be parsed by
- * gtk_accelerator_parse(), e.g. "<Primary>q" or "<Control><Alt>p".
+ * gtk_accelerator_parse(), e.g. "&lt;Primary&gt;q" or
+ * "&lt;Control&gt;&lt;Alt&gt;p".
  *
  * @action_name must be the name of an action as it would be used
  * in the app menu, i.e. actions that have been added to the application
@@ -1352,7 +1353,7 @@ gtk_application_startup_session_dbus (GtkApplication *app)
  * that should not be interrupted, such as creating a CD or DVD. The
  * types of actions that may be blocked are specified by the @flags
  * parameter. When the application completes the operation it should
- * call g_application_uninhibit() to remove the inhibitor. Note that
+ * call gtk_application_uninhibit() to remove the inhibitor. Note that
  * an application can have multiple inhibitors, and all of the must
  * be individually removed. Inhibitors are also cleared when the
  * application exits.
@@ -1367,7 +1368,7 @@ gtk_application_startup_session_dbus (GtkApplication *app)
  * this window to find out more about why the action is inhibited.
  *
  * Returns: A non-zero cookie that is used to uniquely identify this
- *     request. It should be used as an argument to g_application_uninhibit()
+ *     request. It should be used as an argument to gtk_application_uninhibit()
  *     in order to remove the request. If the platform does not support
  *     inhibiting or the request failed for some reason, 0 is returned.
  *
@@ -1420,9 +1421,9 @@ gtk_application_inhibit (GtkApplication             *application,
 /**
  * gtk_application_uninhibit:
  * @application: the #GApplication
- * @cookie: a cookie that was returned by g_application_inhibit()
+ * @cookie: a cookie that was returned by gtk_application_inhibit()
  *
- * Removes an inhibitor that has been established with g_application_inhibit().
+ * Removes an inhibitor that has been established with gtk_application_inhibit().
  * Inhibitors are also cleared when the application exits.
  *
  * Since: 3.4
diff --git a/gtk/gtkapplicationwindow.c b/gtk/gtkapplicationwindow.c
index ab98920..9b27edf 100644
--- a/gtk/gtkapplicationwindow.c
+++ b/gtk/gtkapplicationwindow.c
@@ -75,7 +75,7 @@
  * will display the application menu, but not the menubar.
  *
  * If the desktop environment does not display the menubar, then
- * #GApplicationWindow will automatically show a #GtkMenubar for it.
+ * #GtkApplicationWindow will automatically show a #GtkMenuBar for it.
  * (see the #GtkApplication docs for some screenshots of how this
  * looks on different platforms).
  * This behaviour can be overridden with the #GtkApplicationWindow:show-menubar
diff --git a/gtk/gtkcelleditable.c b/gtk/gtkcelleditable.c
index 23b266d..7302549 100644
--- a/gtk/gtkcelleditable.c
+++ b/gtk/gtkcelleditable.c
@@ -120,7 +120,7 @@ gtk_cell_editable_start_editing (GtkCellEditable *cell_editable,
 
 /**
  * gtk_cell_editable_editing_done:
- * @cell_editable: A #GtkTreeEditable
+ * @cell_editable: A #GtkCellEditable
  * 
  * Emits the #GtkCellEditable::editing-done signal. 
  **/
@@ -134,7 +134,7 @@ gtk_cell_editable_editing_done (GtkCellEditable *cell_editable)
 
 /**
  * gtk_cell_editable_remove_widget:
- * @cell_editable: A #GtkTreeEditable
+ * @cell_editable: A #GtkCellEditable
  * 
  * Emits the #GtkCellEditable::remove-widget signal.  
  **/
diff --git a/gtk/gtkcelllayout.c b/gtk/gtkcelllayout.c
index b34bb24..f9e0ce8 100644
--- a/gtk/gtkcelllayout.c
+++ b/gtk/gtkcelllayout.c
@@ -21,7 +21,7 @@
  * @Title: GtkCellLayout
  *
  * #GtkCellLayout is an interface to be implemented by all objects which
- * want to provide a #GtkTreeViewColumn-like API for packing cells, setting
+ * want to provide a #GtkTreeViewColumn<!-- -->-like API for packing cells, setting
  * attributes and data funcs.
  *
  * One of the notable features provided by implementations of GtkCellLayout
@@ -38,7 +38,7 @@
  * <title>GtkCellLayouts as GtkBuildable</title>
  * <para>
  * Implementations of GtkCellLayout which also implement the GtkBuildable
- * interface (#GtkCellView, #GtkIconView, #GtkComboBox, #GtkComboBoxEntry,
+ * interface (#GtkCellView, #GtkIconView, #GtkComboBox,
  * #GtkEntryCompletion, #GtkTreeViewColumn) accept GtkCellRenderer objects
  * as &lt;child&gt; elements in UI definitions. They support a custom
  * &lt;attributes&gt; element for their children, which can contain
diff --git a/gtk/gtkcellrenderercombo.c b/gtk/gtkcellrenderercombo.c
index 2e8001b..d3cfb57 100644
--- a/gtk/gtkcellrenderercombo.c
+++ b/gtk/gtkcellrenderercombo.c
@@ -36,7 +36,7 @@
  *
  * #GtkCellRendererCombo renders text in a cell like #GtkCellRendererText from
  * which it is derived. But while #GtkCellRendererText offers a simple entry to
- * edit the text, #GtkCellRendererCombo offers a #GtkComboBox or #GtkComboBoxEntry
+ * edit the text, #GtkCellRendererCombo offers a #GtkComboBox
  * widget to edit the text. The values to display in the combo box are taken from
  * the tree model specified in the #GtkCellRendererCombo:model property.
  *
diff --git a/gtk/gtkcssprovider.c b/gtk/gtkcssprovider.c
index 848fc8a..137f3ae 100644
--- a/gtk/gtkcssprovider.c
+++ b/gtk/gtkcssprovider.c
@@ -916,7 +916,7 @@
  *       <row>
  *         <entry>text-shadow</entry>
  *         <entry>shadow list (see above)</entry>
- *         <entry>#GtkTextShadow</entry>
+ *         <entry>internal use only</entry>
  *         <entry><literallayout>text-shadow: 1 1 0 blue, -4 -4 red;</literallayout></entry>
  *       </row>
  *       <row>
diff --git a/gtk/gtkcsssection.c b/gtk/gtkcsssection.c
index 85fd064..58383c6 100644
--- a/gtk/gtkcsssection.c
+++ b/gtk/gtkcsssection.c
@@ -168,10 +168,10 @@ gtk_css_section_get_section_type (const GtkCssSection *section)
  *
  * Gets the parent section for the given @section. The parent section is
  * the section that contains this @section. A special case are sections of
- * type #GTK_CSS_SECTION_TYPE_DOCUMENT. Their parent will either be %NULL
+ * type #GTK_CSS_SECTION_DOCUMENT. Their parent will either be %NULL
  * if they are the original CSS document that was loaded by
  * gtk_css_provider_load_from_file() or a section of type
- * #GTK_CSS_SECTION_TYPE_IMPORT if it was loaded with an import rule from
+ * #GTK_CSS_SECTION_IMPORT if it was loaded with an import rule from
  * a different file.
  *
  * Returns: the parent section or %NULL if none
diff --git a/gtk/gtkentry.c b/gtk/gtkentry.c
index cfb6ba5..ef58c2e 100644
--- a/gtk/gtkentry.c
+++ b/gtk/gtkentry.c
@@ -7197,7 +7197,7 @@ gtk_entry_get_text_length (GtkEntry *entry)
  *
  * (For experts: if @setting is %TRUE, the entry calls
  * gtk_window_activate_default() on the window containing the entry, in
- * the default handler for the #GtkWidget::activate signal.)
+ * the default handler for the #GtkEntry::activate signal.)
  **/
 void
 gtk_entry_set_activates_default (GtkEntry *entry,
@@ -8202,7 +8202,7 @@ gtk_entry_get_icon_at_pos (GtkEntry *entry,
 
 /**
  * gtk_entry_set_icon_drag_source:
- * @entry: a #GtkIconEntry
+ * @entry: a #GtkEntry
  * @icon_pos: icon position
  * @target_list: the targets (data formats) in which the data can be provided
  * @actions: a bitmask of the allowed drag actions
@@ -8495,7 +8495,7 @@ gtk_entry_get_icon_tooltip_markup (GtkEntry             *entry,
  * Use %NULL for @tooltip to remove an existing tooltip.
  *
  * See also gtk_widget_set_tooltip_markup() and 
- * gtk_enty_set_icon_tooltip_text().
+ * gtk_entry_set_icon_tooltip_text().
  *
  * Since: 2.16
  */
diff --git a/gtk/gtkfilechooserdialog.c b/gtk/gtkfilechooserdialog.c
index c120b9c..01fe9af 100644
--- a/gtk/gtkfilechooserdialog.c
+++ b/gtk/gtkfilechooserdialog.c
@@ -42,7 +42,7 @@
  * #GtkFileChooserDialog is a dialog box suitable for use with
  * "File/Open" or "File/Save as" commands.  This widget works by
  * putting a #GtkFileChooserWidget inside a #GtkDialog.  It exposes
- * the #GtkFileChooserIface interface, so you can use all of the
+ * the #GtkFileChooser interface, so you can use all of the
  * #GtkFileChooser functions on the file chooser dialog as well as
  * those for #GtkDialog.
  *
diff --git a/gtk/gtkiconview.c b/gtk/gtkiconview.c
index 9e8e1e2..6d3a6e8 100644
--- a/gtk/gtkiconview.c
+++ b/gtk/gtkiconview.c
@@ -6748,7 +6748,7 @@ gtk_icon_view_drag_data_received (GtkWidget        *widget,
 /* Drag-and-Drop support */
 /**
  * gtk_icon_view_enable_model_drag_source:
- * @icon_view: a #GtkIconTreeView
+ * @icon_view: a #GtkIconView
  * @start_button_mask: Mask of allowed buttons to start drag
  * @targets: (array length=n_targets): the table of targets that the drag will
  *           support
diff --git a/gtk/gtklabel.c b/gtk/gtklabel.c
index b481ac5..bb3ca4f 100644
--- a/gtk/gtklabel.c
+++ b/gtk/gtklabel.c
@@ -66,7 +66,7 @@
  *
  * The #GtkLabel widget displays a small amount of text. As the name
  * implies, most labels are used to label another widget such as a
- * #GtkButton, a #GtkMenuItem, or a #GtkOptionMenu.
+ * #GtkButton, a #GtkMenuItem, or a #GtkComboBox.
  *
  * <refsect2 id="GtkLabel-BUILDER-UI">
  * <title>GtkLabel as GtkBuildable</title>
@@ -840,7 +840,7 @@ gtk_label_class_init (GtkLabelClass *class)
    *
    * The preferred place to ellipsize the string, if the label does 
    * not have enough room to display the entire string, specified as a 
-   * #PangoEllisizeMode. 
+   * #PangoEllipsizeMode. 
    *
    * Note that setting this property to a value other than 
    * %PANGO_ELLIPSIZE_NONE has the side-effect that the label requests 
@@ -1965,9 +1965,9 @@ gtk_label_get_mnemonic_widget (GtkLabel *label)
  *
  * If the label has been set so that it has an mnemonic key this function
  * returns the keyval used for the mnemonic accelerator. If there is no
- * mnemonic set up it returns #GDK_VoidSymbol.
+ * mnemonic set up it returns #GDK_KEY_VoidSymbol.
  *
- * Returns: GDK keyval usable for accelerators, or #GDK_VoidSymbol
+ * Returns: GDK keyval usable for accelerators, or #GDK_KEY_VoidSymbol
  **/
 guint
 gtk_label_get_mnemonic_keyval (GtkLabel *label)
diff --git a/gtk/gtkmain.c b/gtk/gtkmain.c
index c9f9173..596a3fb 100644
--- a/gtk/gtkmain.c
+++ b/gtk/gtkmain.c
@@ -1441,8 +1441,7 @@ rewrite_event_for_grabs (GdkEvent *event)
  * </para></listitem>
  * <listitem><para>
  *   Find the widget which got the event. If the widget can't be determined
- *   the event is thrown away unless it belongs to a INCR transaction. In that
- *   case it is passed to gtk_selection_incr_event().
+ *   the event is thrown away unless it belongs to a INCR transaction.
  * </para></listitem>
  * <listitem><para>
  *   Then the event is pushed onto a stack so you can query the currently
@@ -2108,7 +2107,7 @@ gtk_grab_remove (GtkWidget *widget)
 /**
  * gtk_device_grab_add:
  * @widget: a #GtkWidget
- * @device: a #GtkDevice to grab on.
+ * @device: a #GdkDevice to grab on.
  * @block_others: %TRUE to prevent other devices to interact with @widget.
  *
  * Adds a GTK+ grab on @device, so all the events on @device and its
diff --git a/gtk/gtkmenu.c b/gtk/gtkmenu.c
index fb995aa..b0912f9 100644
--- a/gtk/gtkmenu.c
+++ b/gtk/gtkmenu.c
@@ -35,7 +35,7 @@
  * #GtkMenuItem in a #GtkMenuBar or popped up by activating a
  * #GtkMenuItem in another #GtkMenu.
  *
- * A #GtkMenu can also be popped up by activating a #GtkOptionMenu.
+ * A #GtkMenu can also be popped up by activating a #GtkComboBox.
  * Other composite widgets such as the #GtkNotebook can pop up a
  * #GtkMenu as well.
  *
@@ -1863,7 +1863,7 @@ gtk_menu_popdown (GtkMenu *menu)
  * @menu: a #GtkMenu
  *
  * Returns the selected menu item from the menu.  This is used by the
- * #GtkOptionMenu.
+ * #GtkComboBox.
  *
  * Returns: (transfer none): the #GtkMenuItem that was last selected
  *          in the menu.  If a selection has not yet been made, the
@@ -1908,7 +1908,7 @@ gtk_menu_get_active (GtkMenu *menu)
  *         from 0 to n-1
  *
  * Selects the specified menu item within the menu.  This is used by
- * the #GtkOptionMenu and should not be used by anyone else.
+ * the #GtkComboBox and should not be used by anyone else.
  */
 void
 gtk_menu_set_active (GtkMenu *menu,
diff --git a/gtk/gtknotebook.c b/gtk/gtknotebook.c
index 54c079d..5be63f6 100644
--- a/gtk/gtknotebook.c
+++ b/gtk/gtknotebook.c
@@ -1069,7 +1069,7 @@ gtk_notebook_class_init (GtkNotebookClass *class)
    * a notebook where the tab will be attached. It is also
    * responsible for moving/resizing the window and adding the
    * necessary properties to the notebook (e.g. the
-   * #GtkNotebook:group ).
+   * #GtkNotebook:group-name ).
    *
    * Returns: (transfer none): a #GtkNotebook that @page should be
    *     added to, or %NULL.
diff --git a/gtk/gtkprintunixdialog.c b/gtk/gtkprintunixdialog.c
index 30a8c76..f2948f5 100644
--- a/gtk/gtkprintunixdialog.c
+++ b/gtk/gtkprintunixdialog.c
@@ -3948,7 +3948,7 @@ gtk_print_unix_dialog_set_current_page (GtkPrintUnixDialog *dialog,
  * gtk_print_unix_dialog_get_current_page:
  * @dialog: a #GtkPrintUnixDialog
  *
- * Gets the current page of the #GtkPrintDialog.
+ * Gets the current page of the #GtkPrintUnixDialog.
  *
  * Returns: the current page of @dialog
  *
diff --git a/gtk/gtkprogressbar.c b/gtk/gtkprogressbar.c
index 98bc781..6b4cf72 100644
--- a/gtk/gtkprogressbar.c
+++ b/gtk/gtkprogressbar.c
@@ -203,7 +203,7 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
    *
    * The preferred place to ellipsize the string, if the progress bar does
    * not have enough room to display the entire string, specified as a
-   * #PangoEllisizeMode.
+   * #PangoEllipsizeMode.
    *
    * Note that setting this property to a value other than
    * %PANGO_ELLIPSIZE_NONE has the side-effect that the progress bar requests
diff --git a/gtk/gtkradiotoolbutton.c b/gtk/gtkradiotoolbutton.c
index 6c964ed..ab849ed 100644
--- a/gtk/gtkradiotoolbutton.c
+++ b/gtk/gtkradiotoolbutton.c
@@ -159,7 +159,7 @@ gtk_radio_tool_button_new (GSList *group)
  * The new #GtkRadioToolButton will contain an icon and label from the
  * stock item indicated by @stock_id.
  * 
- * Return value: The new #GtkRadioToolItem
+ * Return value: The new #GtkRadioToolButton
  * 
  * Since: 2.4
  **/
diff --git a/gtk/gtkrecentchooser.h b/gtk/gtkrecentchooser.h
index ae222c6..945dfa0 100644
--- a/gtk/gtkrecentchooser.h
+++ b/gtk/gtkrecentchooser.h
@@ -44,7 +44,7 @@ G_BEGIN_DECLS
  * @GTK_RECENT_SORT_LRU: Sort the returned list with the least recently used
  *   items first.
  * @GTK_RECENT_SORT_CUSTOM: Sort the returned list using a custom sorting
- *   function passed using gtk_recent_manager_set_sort_func().
+ *   function passed using gtk_recent_chooser_set_sort_func().
  *
  * Used to specify the sorting method to be applyed to the recently
  * used resource list.
diff --git a/gtk/gtkscrollbar.c b/gtk/gtkscrollbar.c
index eb5ee5a..541acc3 100644
--- a/gtk/gtkscrollbar.c
+++ b/gtk/gtkscrollbar.c
@@ -45,12 +45,12 @@
  *
  * The position of the thumb in a scrollbar is controlled by the scroll
  * adjustments. See #GtkAdjustment for the fields in an adjustment - for
- * #GtkScrollbar, the #GtkAdjustment.value field represents the position
- * of the scrollbar, which must be between the #GtkAdjustment.lower field
- * and #GtkAdjustment.upper - #GtkAdjustment.page_size. The
- * #GtkAdjustment.page_size field represents the size of the visible
- * scrollable area. The #GtkAdjustment.step_increment and
- * #GtkAdjustment.page_increment fields are used when the user asks to
+ * #GtkScrollbar, the #GtkAdjustment:value field represents the position
+ * of the scrollbar, which must be between the #GtkAdjustment:lower field
+ * and #GtkAdjustment:upper - #GtkAdjustment:page-size. The
+ * #GtkAdjustment:page-size field represents the size of the visible
+ * scrollable area. The #GtkAdjustment:step-increment and
+ * #GtkAdjustment:page-increment fields are properties when the user asks to
  * step down (using the small stepper arrows) or page down (using for
  * example the <keycap>PageDown</keycap> key).
  */
diff --git a/gtk/gtkselection.c b/gtk/gtkselection.c
index 008d99c..67a774f 100644
--- a/gtk/gtkselection.c
+++ b/gtk/gtkselection.c
@@ -661,8 +661,8 @@ gtk_target_table_free (GtkTargetEntry *targets,
 
 /**
  * gtk_selection_owner_set_for_display:
- * @display: the #Gdkdisplay where the selection is set
- * @widget: (allow-none): new selection owner (a #GdkWidget), or %NULL.
+ * @display: the #GdkDisplay where the selection is set
+ * @widget: (allow-none): new selection owner (a #GtkWidget), or %NULL.
  * @selection: an interned atom representing the selection to claim.
  * @time_: timestamp with which to claim the selection
  *
diff --git a/gtk/gtkselection.h b/gtk/gtkselection.h
index 402a0dc..a86a1ca 100644
--- a/gtk/gtkselection.h
+++ b/gtk/gtkselection.h
@@ -54,7 +54,7 @@ typedef struct _GtkTargetEntry GtkTargetEntry;
  * @target: a string representation of the target type
  * @flags: #GtkTargetFlags for DND
  * @info: an application-assigned integer ID which will
- *     get passed as a parater to e.g the #GtkWiget::selection-get
+ *     get passed as a parater to e.g the #GtkWidget::selection-get
  *     signal. It allows the application to identify the target
  *     type without extensive string compares.
  *
diff --git a/gtk/gtkseparatortoolitem.c b/gtk/gtkseparatortoolitem.c
index d8ce1f3..5df1199 100644
--- a/gtk/gtkseparatortoolitem.c
+++ b/gtk/gtkseparatortoolitem.c
@@ -31,7 +31,7 @@
  * @Title: GtkSeparatorToolItem
  * @See_also: #GtkToolbar, #GtkRadioToolButton
  *
- * A #GtkSeparatorItem is a #GtkToolItem that separates groups of other
+ * A #GtkSeparatorToolItem is a #GtkToolItem that separates groups of other
  * #GtkToolItems. Depending on the theme, a #GtkSeparatorToolItem will
  * often look like a vertical line on horizontally docked toolbars.
  *
diff --git a/gtk/gtkstatusbar.c b/gtk/gtkstatusbar.c
index 07b744b..4735037 100644
--- a/gtk/gtkstatusbar.c
+++ b/gtk/gtkstatusbar.c
@@ -390,10 +390,10 @@ gtk_statusbar_push (GtkStatusbar *statusbar,
 
 /**
  * gtk_statusbar_pop:
- * @statusbar: a #GtkStatusBar
+ * @statusbar: a #GtkStatusbar
  * @context_id: a context identifier
  * 
- * Removes the first message in the #GtkStatusBar's stack
+ * Removes the first message in the #GtkStatusbar's stack
  * with the given context id. 
  *
  * Note that this may not change the displayed message, if 
@@ -440,7 +440,7 @@ gtk_statusbar_pop (GtkStatusbar *statusbar,
 
 /**
  * gtk_statusbar_remove:
- * @statusbar: a #GtkStatusBar
+ * @statusbar: a #GtkStatusbar
  * @context_id: a context identifier
  * @message_id: a message identifier, as returned by gtk_statusbar_push()
  *
@@ -492,7 +492,7 @@ gtk_statusbar_remove (GtkStatusbar *statusbar,
 
 /**
  * gtk_statusbar_remove_all:
- * @statusbar: a #GtkStatusBar
+ * @statusbar: a #GtkStatusbar
  * @context_id: a context identifier
  *
  * Forces the removal of all messages from a statusbar's
@@ -563,7 +563,7 @@ gtk_statusbar_remove_all (GtkStatusbar *statusbar,
 
 /**
  * gtk_statusbar_get_message_area:
- * @statusbar: a #GtkStatusBar
+ * @statusbar: a #GtkStatusbar
  *
  * Retrieves the box containing the label widget.
  *
diff --git a/gtk/gtkthemingengine.c b/gtk/gtkthemingengine.c
index b4e2538..e5012a9 100644
--- a/gtk/gtkthemingengine.c
+++ b/gtk/gtkthemingengine.c
@@ -781,7 +781,7 @@ gtk_theming_engine_get_border_color (GtkThemingEngine *engine,
 
 /**
  * gtk_theming_engine_get_border:
- * @engine: a #GtkthemingEngine
+ * @engine: a #GtkThemingEngine
  * @state: state to retrieve the border for
  * @border: (out): return value for the border settings
  *
@@ -804,7 +804,7 @@ gtk_theming_engine_get_border (GtkThemingEngine *engine,
 
 /**
  * gtk_theming_engine_get_padding:
- * @engine: a #GtkthemingEngine
+ * @engine: a #GtkThemingEngine
  * @state: state to retrieve the padding for
  * @padding: (out): return value for the padding settings
  *
diff --git a/gtk/gtktogglebutton.c b/gtk/gtktogglebutton.c
index 6b1664e..a5d9497 100644
--- a/gtk/gtktogglebutton.c
+++ b/gtk/gtktogglebutton.c
@@ -49,7 +49,7 @@
  *
  * A toggle button is created by calling either gtk_toggle_button_new() or
  * gtk_toggle_button_new_with_label(). If using the former, it is advisable to
- * pack a widget, (such as a #GtkLabel and/or a #GtkPixmap), into the toggle
+ * pack a widget, (such as a #GtkLabel and/or a #GtkImage), into the toggle
  * button's container. (See #GtkButton for more information).
  *
  * The state of a #GtkToggleButton can be set specifically using
diff --git a/gtk/gtktoolbutton.c b/gtk/gtktoolbutton.c
index 1999458..cf8a22d 100644
--- a/gtk/gtktoolbutton.c
+++ b/gtk/gtktoolbutton.c
@@ -46,7 +46,7 @@
  * #GtkToolButton<!-- -->s are #GtkToolItems containing buttons.
  *
  * Use gtk_tool_button_new() to create a new #GtkToolButton. Use
- * gtk_tool_button_new_with_stock() to create a #GtkToolButton
+ * gtk_tool_button_new_from_stock() to create a #GtkToolButton
  * containing a stock item.
  *
  * The label of a #GtkToolButton is determined by the properties
diff --git a/gtk/gtktoolitem.c b/gtk/gtktoolitem.c
index d569243..adae769 100644
--- a/gtk/gtktoolitem.c
+++ b/gtk/gtktoolitem.c
@@ -785,10 +785,7 @@ gtk_tool_item_get_orientation (GtkToolItem *tool_item)
  * <listitem> GTK_TOOLBAR_TEXT, meaning the tool item should only
  * show text</listitem>
  * <listitem> GTK_TOOLBAR_BOTH_HORIZ, meaning the tool item should show
- * both an icon and a label, arranged horizontally (however, note the 
- * #GtkToolButton:has_text_horizontally property that makes tool buttons not
- * show labels when the toolbar style is GTK_TOOLBAR_BOTH_HORIZ.
- * </listitem>
+ * both an icon and a label, arranged horizontally</listitem>
  * </itemizedlist>
  * 
  * Return value: A #GtkToolbarStyle indicating the toolbar style used
@@ -814,7 +811,7 @@ gtk_tool_item_get_toolbar_style (GtkToolItem *tool_item)
  * gtk_tool_item_get_relief_style:
  * @tool_item: a #GtkToolItem 
  * 
- * Returns the relief style of @tool_item. See gtk_button_set_relief_style().
+ * Returns the relief style of @tool_item. See gtk_button_set_relief().
  * Custom subclasses of #GtkToolItem should call this function in the handler
  * of the #GtkToolItem::toolbar_reconfigured signal to find out the
  * relief style of buttons.
diff --git a/gtk/gtktoolpalette.c b/gtk/gtktoolpalette.c
index 0655bff..9d8cd04 100644
--- a/gtk/gtktoolpalette.c
+++ b/gtk/gtktoolpalette.c
@@ -989,7 +989,7 @@ gtk_tool_palette_class_init (GtkToolPaletteClass *cls)
    * GtkToolPalette:icon-size:
    *
    * The size of the icons in a tool palette is normally determined by
-   * the #GtkSettings:toolbar-icon-size setting. When this property is set,
+   * the #GtkSettings:gtk-toolbar-icon-size setting. When this property is set,
    * it overrides the setting.
    *
    * This should only be used for special-purpose tool palettes, normal
@@ -1673,7 +1673,7 @@ gtk_tool_palette_get_drag_item (GtkToolPalette         *palette,
 /**
  * gtk_tool_palette_set_drag_source:
  * @palette: a #GtkToolPalette
- * @targets: the #GtkToolPaletteDragTarget<!-- -->s
+ * @targets: the #GtkToolPaletteDragTargets
  *     which the widget should support
  *
  * Sets the tool palette as a drag source.
@@ -1712,7 +1712,7 @@ gtk_tool_palette_set_drag_source (GtkToolPalette            *palette,
  * @widget: a #GtkWidget which should be a drag destination for @palette
  * @flags: the flags that specify what actions GTK+ should take for drops
  *     on that widget
- * @targets: the #GtkToolPaletteDragTarget<!-- -->s which the widget
+ * @targets: the #GtkToolPaletteDragTargets which the widget
  *     should support
  * @actions: the #GdkDragAction<!-- -->s which the widget should suppport
  *
diff --git a/gtk/gtktreeview.c b/gtk/gtktreeview.c
index 93ccb6e..7bb7fc9 100644
--- a/gtk/gtktreeview.c
+++ b/gtk/gtktreeview.c
@@ -11350,7 +11350,7 @@ gtk_tree_view_get_model (GtkTreeView *tree_view)
 
 /**
  * gtk_tree_view_set_model:
- * @tree_view: A #GtkTreeNode.
+ * @tree_view: A #GtkTreeView.
  * @model: (allow-none): The model.
  *
  * Sets the model for a #GtkTreeView.  If the @tree_view already has a model
@@ -12141,7 +12141,7 @@ gtk_tree_view_insert_column_with_attributes (GtkTreeView     *tree_view,
  * @dnotify: destroy notifier for @data
  *
  * Convenience function that inserts a new column into the #GtkTreeView
- * with the given cell renderer and a #GtkCellDataFunc to set cell renderer
+ * with the given cell renderer and a #GtkTreeCellDataFunc to set cell renderer
  * attributes (normally using data from the model). See also
  * gtk_tree_view_column_set_cell_data_func(), gtk_tree_view_column_pack_start().
  * If @tree_view has "fixed_height" mode enabled, then the new column will have its
diff --git a/gtk/gtktreeviewcolumn.c b/gtk/gtktreeviewcolumn.c
index 670bcaf..c9c0be5 100644
--- a/gtk/gtktreeviewcolumn.c
+++ b/gtk/gtktreeviewcolumn.c
@@ -1822,11 +1822,11 @@ gtk_tree_view_column_set_attributes (GtkTreeViewColumn *tree_column,
  * gtk_tree_view_column_set_cell_data_func:
  * @tree_column: A #GtkTreeViewColumn
  * @cell_renderer: A #GtkCellRenderer
- * @func: (allow-none): The #GtkTreeViewColumnFunc to use. 
+ * @func: (allow-none): The #GtkTreeCellDataFunc to use. 
  * @func_data: The user data for @func.
  * @destroy: The destroy notification for @func_data
  * 
- * Sets the #GtkTreeViewColumnFunc to use for the column.  This
+ * Sets the #GtkTreeCellDataFunc to use for the column.  This
  * function is used instead of the standard attributes mapping for
  * setting the column value, and should set the value of @tree_column's
  * cell renderer as appropriate.  @func may be %NULL to remove an
@@ -2807,7 +2807,7 @@ gtk_tree_view_column_get_sort_indicator  (GtkTreeViewColumn     *tree_column)
  * This <emphasis>does not</emphasis> actually sort the model.  Use
  * gtk_tree_view_column_set_sort_column_id() if you want automatic sorting
  * support.  This function is primarily for custom sorting behavior, and should
- * be used in conjunction with gtk_tree_sortable_set_sort_column() to do
+ * be used in conjunction with gtk_tree_sortable_set_sort_column_id() to do
  * that. For custom models, the mechanism will vary. 
  * 
  * The sort indicator changes direction to indicate normal sort or reverse sort.
diff --git a/gtk/gtktreeviewcolumn.h b/gtk/gtktreeviewcolumn.h
index 9555ab2..6666909 100644
--- a/gtk/gtktreeviewcolumn.h
+++ b/gtk/gtktreeviewcolumn.h
@@ -61,7 +61,7 @@ typedef enum
 
 /**
  * GtkTreeCellDataFunc:
- * @tree_column: A #GtkTreeColumn
+ * @tree_column: A #GtkTreeViewColumn
  * @cell: The #GtkCellRenderer that is being rendered by @tree_column
  * @tree_model: The #GtkTreeModel being rendered
  * @iter: A #GtkTreeIter of the current row rendered
diff --git a/gtk/gtkviewport.c b/gtk/gtkviewport.c
index 03b05e2..5ac403b 100644
--- a/gtk/gtkviewport.c
+++ b/gtk/gtkviewport.c
@@ -46,7 +46,7 @@
  * #GtkGrid, #GtkBox, and so on.
  *
  * If a widget has native scrolling abilities, such as #GtkTextView,
- * #GtkTreeView or #GtkIconview, it can be added to a #GtkScrolledWindow
+ * #GtkTreeView or #GtkIconView, it can be added to a #GtkScrolledWindow
  * with gtk_container_add(). If a widget does not, you must first add the
  * widget to a #GtkViewport, then add the viewport to the scrolled window.
  * The convenience function gtk_scrolled_window_add_with_viewport() does
diff --git a/gtk/gtkwidget.c b/gtk/gtkwidget.c
index daee052..c7a2342 100644
--- a/gtk/gtkwidget.c
+++ b/gtk/gtkwidget.c
@@ -2533,7 +2533,7 @@ gtk_widget_class_init (GtkWidgetClass *klass)
    *
    * The ::drag-begin signal is emitted on the drag source when a drag is
    * started. A typical reason to connect to this signal is to set up a
-   * custom drag icon with gtk_drag_source_set_icon().
+   * custom drag icon with e.g. gtk_drag_source_set_icon_pixbuf().
    *
    * Note that some widgets set up a drag icon in the default handler of
    * this signal, so you may have to use g_signal_connect_after() to
@@ -5369,7 +5369,7 @@ widget_new_accel_closure (GtkWidget *widget,
  * Installs an accelerator for this @widget in @accel_group that causes
  * @accel_signal to be emitted if the accelerator is activated.
  * The @accel_group needs to be added to the widget's toplevel via
- * gtk_window_add_accel_group(), and the signal must be of type %G_RUN_ACTION.
+ * gtk_window_add_accel_group(), and the signal must be of type %G_SIGNAL_ACTION.
  * Accelerators added through this function are not user changeable during
  * runtime. If you want to support accelerators that can be changed by the
  * user, use gtk_accel_map_add_entry() and gtk_widget_set_accel_path() or
@@ -7010,10 +7010,10 @@ _gtk_widget_set_has_default (GtkWidget *widget,
  * gtk_widget_grab_default:
  * @widget: a #GtkWidget
  *
- * Causes @widget to become the default widget. @widget must have the
- * %GTK_CAN_DEFAULT flag set; typically you have to set this flag
- * yourself by calling <literal>gtk_widget_set_can_default (@widget,
- * %TRUE)</literal>. The default widget is activated when
+ * Causes @widget to become the default widget. @widget must be able to be
+ * a default widget; typically you would ensure this yourself
+ * by calling gtk_widget_set_can_default() with a %TRUE value.
+ * The default widget is activated when
  * the user presses Enter in a window. Default widgets must be
  * activatable, that is, gtk_widget_activate() should affect them. Note
  * that #GtkEntry widgets require the "activates-default" property
@@ -7729,7 +7729,7 @@ gtk_widget_get_app_paintable (GtkWidget *widget)
  * to turn off the buffering. "Double buffered" simply means that
  * gdk_window_begin_paint_region() and gdk_window_end_paint() are called
  * automatically around expose events sent to the
- * widget. gdk_window_begin_paint() diverts all drawing to a widget's
+ * widget. gdk_window_begin_paint_region() diverts all drawing to a widget's
  * window to an offscreen buffer, and gdk_window_end_paint() draws the
  * buffer to the screen. The result is that users see the window
  * update in one smooth step, and don't see individual graphics
@@ -7742,7 +7742,7 @@ gtk_widget_get_app_paintable (GtkWidget *widget)
  * Note: if you turn off double-buffering, you have to handle
  * expose events, since even the clearing to the background color or
  * pixmap will not happen automatically (as it is done in
- * gdk_window_begin_paint()).
+ * gdk_window_begin_paint_region()).
  **/
 void
 gtk_widget_set_double_buffered (GtkWidget *widget,
@@ -9713,7 +9713,7 @@ gtk_widget_add_device_events (GtkWidget    *widget,
  * <literal>gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW)</literal>
  * would return
  * %NULL if @widget wasn't inside a toplevel window, and if the
- * window was inside a #GtkWindow-derived widget which was in turn
+ * window was inside a #GtkWindow<!-- -->-derived widget which was in turn
  * inside the toplevel #GtkWindow. While the second case may
  * seem unlikely, it actually happens when a #GtkPlug is embedded
  * inside a #GtkSocket within the same application.
@@ -9782,7 +9782,7 @@ gtk_widget_get_ancestor (GtkWidget *widget,
  *
  * Sets the visual that should be used for by widget and its children for
  * creating #GdkWindows. The visual must be on the same #GdkScreen as
- * returned by gdk_widget_get_screen(), so handling the
+ * returned by gtk_widget_get_screen(), so handling the
  * #GtkWidget::screen-changed signal is necessary.
  *
  * Setting a new @visual will not cause @widget to recreate its windows,
diff --git a/gtk/gtkwidget.h b/gtk/gtkwidget.h
index b153dff..94189dd 100644
--- a/gtk/gtkwidget.h
+++ b/gtk/gtkwidget.h
@@ -160,7 +160,7 @@ struct _GtkWidget
  *   method it is possible for a #GtkLabel to tell its parent how much height
  *   would be required if the label were to be allocated a said width.
  * @adjust_size_request: Convert an initial size request from a widget's
- *   #GtkSizeRequest virtual method implementations into a size request to
+ *   #GtkSizeRequestMode virtual method implementations into a size request to
  *   be used by parent containers in laying out the widget.
  *   adjust_size_request adjusts <emphasis>from</emphasis> a child widget's
  *   original request <emphasis>to</emphasis> what a parent container should
diff --git a/gtk/gtkwindow.c b/gtk/gtkwindow.c
index 9843229..d39beed 100644
--- a/gtk/gtkwindow.c
+++ b/gtk/gtkwindow.c
@@ -1927,8 +1927,8 @@ _gtk_window_internal_set_focus (GtkWindow *window,
  * unsets the default widget for a #GtkWindow about. When setting
  * (rather than unsetting) the default widget it's generally easier to
  * call gtk_widget_grab_focus() on the widget. Before making a widget
- * the default widget, you must set the #GTK_CAN_DEFAULT flag on the
- * widget you'd like to make the default using GTK_WIDGET_SET_FLAGS().
+ * the default widget, you must call gtk_widget_set_can_default() on the
+ * widget you'd like to make the default.
  **/
 void
 gtk_window_set_default (GtkWindow *window,
@@ -3401,7 +3401,7 @@ gtk_window_get_decorated (GtkWindow *window)
  * using this function, GTK+ will do its best to convince the window
  * manager not to show a close button. Depending on the system, this
  * function may not have any effect when called on a window that is
- * already visible, so you should call it before calling gtk_window_show().
+ * already visible, so you should call it before calling gtk_widget_show().
  *
  * On Windows, this function always works, since there's no window manager
  * policy involved.
@@ -9818,7 +9818,7 @@ _gtk_window_get_wmclass (GtkWindow  *window,
  * @setting: the new value
  *
  * Tells GTK+ whether to drop its extra reference to the window
- * when gtk_window_destroy() is called.
+ * when gtk_widget_destroy() is called.
  *
  * This function is only exported for the benefit of language
  * bindings which may need to keep the window alive until their



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkprintoperation.c b/gtk/gtkprintoperation.c
index 90b8d8a..937889d 100644
--- a/gtk/gtkprintoperation.c
+++ b/gtk/gtkprintoperation.c
@@ -96,7 +96,7 @@
  * By default GtkPrintOperation uses an external application to do
  * print preview. To implement a custom print preview, an application
  * must connect to the preview signal. The functions
- * gtk_print_operation_print_preview_render_page(),
+ * gtk_print_operation_preview_render_page(),
  * gtk_print_operation_preview_end_preview() and
  * gtk_print_operation_preview_is_selected()
  * are useful when implementing a print preview.
@@ -1032,7 +1032,7 @@ gtk_print_operation_class_init (GtkPrintOperationClass *class)
    /**
    * GtkPrintOperation::preview:
    * @operation: the #GtkPrintOperation on which the signal was emitted
-   * @preview: the #GtkPrintPreviewOperation for the current operation
+   * @preview: the #GtkPrintOperationPreview for the current operation
    * @context: the #GtkPrintContext that will be used
    * @parent: (allow-none): the #GtkWindow to use as window parent, or %NULL
    *
@@ -1400,7 +1400,7 @@ gtk_print_operation_class_init (GtkPrintOperationClass *class)
 				   PROP_EMBED_PAGE_SETUP,
 				   g_param_spec_boolean ("embed-page-setup",
 							 P_("Embed Page Setup"),
-							 P_("TRUE if page setup combos are embedded in GtkPrintDialog"),
+							 P_("TRUE if page setup combos are embedded in GtkPrintUnixDialog"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
   /**
@@ -2389,7 +2389,7 @@ gtk_print_operation_set_defer_drawing (GtkPrintOperation *op)
 /**
  * gtk_print_operation_set_embed_page_setup:
  * @op: a #GtkPrintOperation
  * @embed: %TRUE to embed page setup selection in the #GtkPrintDialog
  *
  * Embed page size combo box and orientation combo box into page setup page.
  * Selected page setup is stored as default page setup in #GtkPrintOperation.
@@ -2389,7 +2389,7 @@ gtk_print_operation_set_defer_drawing (GtkPrintOperation *op)
  * gtk_print_operation_set_embed_page_setup:
  * @op: a #GtkPrintOperation
- * @embed: %TRUE to embed page setup selection in the #GtkPrintDialog
+ * @embed: %TRUE to embed page setup selection in the #GtkPrintUnixDialog
  *
  * Embed page size combo box and orientation combo box into page setup page.